@@ -2,8 +2,14 @@
     Module for the Open Webdriver.
 """
 
+import os
+
 from .open_webdriver import Driver  # type: ignore
 from .open_webdriver import open_webdriver
+from .path import LOG_FILE
+
+if os.path.exists(LOG_FILE):
+    os.remove(LOG_FILE)
 
 
 def test() -> None:
