@@ -2,8 +2,6 @@
     Tests the open_webdriver package.
 """
 
-import os
-import sys
 import unittest
 
 from open_webdriver.open_webdriver import open_webdriver
@@ -19,14 +17,6 @@ def do_google_test(headless: bool) -> bool:
 class OpenWebDriverTests(unittest.TestCase):
     """Tester for open_webdriver.py"""
 
-    @unittest.skipIf(sys.platform != "win32", "Windows only tests")
-    def test_win32_bug(self) -> None:
-        """Asserts that the win32 bug is fixed."""
-        with open_webdriver():
-            pass
-        # This environmental variable should be available now.
-        self.assertIn("PROGRAMW6432", os.environ)
-
     def test_google(self) -> None:
         """Tests that google test works."""
         ok = do_google_test(headless=False)  # pylint: disable=invalid-name
@@ -43,11 +33,8 @@ def package_tests() -> None:
     try:
         _ = do_google_test(headless=True)
         print("\nopen_webdriver_test completed successfully.\n")
-        return
     except Exception as err:  # pylint: disable=broad-except
-        print(f"{__file__}: Error: {err}")
-        print("\n  FAILED: open_webdriver_test")
-        return
+        print(f"\nFAILED: open_webdriver_test because of {err}")
 
 
 def main():
